<?php
/**
 * VW Construction Estate functions and definitions
 *
 * @package VW Construction Estate
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */

/* Theme Setup */

if ( ! function_exists( 'vw_construction_estate_setup' ) ) :

function vw_construction_estate_setup() {

	$GLOBALS['content_width'] = apply_filters( 'vw_construction_estate_content_width', 640 );
	
	load_theme_textdomain( 'vw-construction-estate', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );
	add_image_size('vw-construction-estate-homepage-thumb',240,145,true);
	
       register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'vw-construction-estate' ),
	) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'f1f1f1'
	) );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', vw_construction_estate_font_url() ) );
}
endif;
add_action( 'after_setup_theme', 'vw_construction_estate_setup' );

/* Theme Widgets Setup */
function vw_construction_estate_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'vw-construction-estate' ),
		'description'   => __( 'Appears on blog page sidebar', 'vw-construction-estate' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'vw-construction-estate' ),
		'description'   => __( 'Appears on page sidebar', 'vw-construction-estate' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar 3', 'vw-construction-estate' ),
		'description'   => __( 'Appears on page sidebar', 'vw-construction-estate' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 1', 'vw-construction-estate' ),
		'description'   => __( 'Appears on footer 1', 'vw-construction-estate' ),
		'id'            => 'footer-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 2', 'vw-construction-estate' ),
		'description'   => __( 'Appears on footer 2', 'vw-construction-estate' ),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 3', 'vw-construction-estate' ),
		'description'   => __( 'Appears on footer 3', 'vw-construction-estate' ),
		'id'            => 'footer-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 4', 'vw-construction-estate' ),
		'description'   => __( 'Appears on footer 4', 'vw-construction-estate' ),
		'id'            => 'footer-4',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Home Page Sidebar', 'vw-construction-estate' ),
		'description'   => __( 'Appears on footer 4', 'vw-construction-estate' ),
		'id'            => 'home',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'vw_construction_estate_widgets_init' );

/* Theme Font URL */
function vw_construction_estate_font_url() {
		$font_url = '';
		$font_family = array();
		$font_family[] = 'PT Sans:300,400,600,700,800,900';
		$font_family[] = 'Roboto:400,700';
		$font_family[] = 'Roboto Condensed:400,700';
		$font_family[] = 'Dancing Script';
		$font_family[] = 'Alex Brush';
		$font_family[] = 'Overpass';
		$font_family[] = 'Lato';
		$font_family[] = 'Poppins';
		$font_family[] = 'Libre+Baskerville';
		$font_family[] = 'Muli:200,200i,300,300i,400,400i,600,600i,700,700i,800,800i,900,900i';
		$font_family[] = 'Source+Sans+Pro:200,200i,300,300i,400,400i,600,600i,700,700i,900,900i';
		
		$query_args = array(
			'family'	=> urlencode(implode('|',$font_family)),
		);
		$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
		return $font_url;
}
	
/* Theme enqueue scripts */
function vw_construction_estate_scripts() {
	wp_enqueue_style( 'vw-construction-estate-font', vw_construction_estate_font_url(), array() );
	wp_enqueue_style( 'bootstrap-style', get_template_directory_uri().'/css/bootstrap.css' );
	wp_enqueue_style( 'vw-construction-estate-style', get_stylesheet_uri() );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/css/fontawesome-all.css' );	
	wp_enqueue_style( 'nivo-slider', get_template_directory_uri().'/css/nivo-slider.css' );
	wp_enqueue_style( 'vw-construction-estate-customcss', get_template_directory_uri() . '/css/custom.css' );
	wp_enqueue_script( 'bootstrap-js', get_template_directory_uri() . '/js/bootstrap.js', array('jquery') ,'',true);
	wp_enqueue_script( 'nivo-slider-script', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery'), '', true);
	wp_enqueue_script( 'vw-construction-estate-customscripts', get_template_directory_uri() . '/js/custom.js', array('jquery') );
	wp_enqueue_script( 'SmoothScroll', get_template_directory_uri() . '/js/SmoothScroll.js', array('jquery') );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'vw_construction_estate_scripts' );

function vw_construction_estate_ie_stylesheet(){
	wp_enqueue_style('vw-construction-estate-ie', get_template_directory_uri().'/css/ie.css');
	wp_style_add_data( 'vw-construction-estate-ie', 'conditional', 'IE' );
}
add_action('wp_enqueue_scripts','vw_construction_estate_ie_stylesheet');

define('vw_construction_estate_CREDIT','https://www.vwthemes.com','vw-construction-estate');

if ( ! function_exists( 'vw_construction_estate_credit' ) ) {
	function vw_construction_estate_credit(){
		echo "<a href=".esc_url(vw_construction_estate_CREDIT)." target='_blank'>".esc_html__('VWThemes','vw-construction-estate')."</a>";
	}
}

/*radio button sanitization*/

function vw_construction_estate_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

/* Excerpt Limit Begin */
function vw_construction_estate_string_limit_words($string, $word_limit) {
	$words = explode(' ', $string, ($word_limit + 1));
	if(count($words) > $word_limit)
	array_pop($words);
	return implode(' ', $words);
}


/* Implement the Custom Header feature. */
require get_template_directory() . '/inc/custom-header.php';

/* Custom template tags for this theme. */
require get_template_directory() . '/inc/template-tags.php';

/* Customizer additions. */
require get_template_directory() . '/inc/customizer.php';